@@ -1,11 +1,7 @@
-#include <sys/types.h>
-#include <sys/stat.h>
-
 #include <err.h>
 #include <stdint.h>
 #include <stdlib.h>
 #include <string.h>
-#include <unistd.h>
 
 #include "dedup.h"
 #include "tree.h"
@@ -100,13 +96,3 @@ lookup_cache_entry(struct cache *cache, struct blk_desc *desc)
 	}
 	return -1;
 }
-
-void
-walk_cache(struct cache *cache,
-           int (*fn)(struct blk_desc *, void *), void *arg)
-{
-	struct cache_node *node;
-
-	RB_FOREACH(node, cache_head, &cache->nodes)
-		(*fn)(&node->desc, arg);
-}
